[X2Go-Commits] x2gobroker.git - tmp (branch) updated: 0.0.0.5-30-g4286017

X2Go dev team git-admin at x2go.org
Tue Apr 23 21:08:55 CEST 2013


The branch, tmp has been updated
       via  428601765689aafc634b6be05b4619e7583cf2e6 (commit)
      from  fd53c4a42a79daf8dd3dc209dea8a475599beed6 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
-----------------------------------------------------------------------

Summary of changes:
 etc/broker/x2gobroker-sessionprofiles.conf |    8 +++----
 etc/x2gobroker.conf                        |    8 +++----
 x2gobroker/brokers/base_broker.py          |   32 ++++++++++++++--------------
 x2gobroker/defaults.py                     |    2 +-
 4 files changed, 25 insertions(+), 25 deletions(-)

The diff of changes is:
diff --git a/etc/broker/x2gobroker-sessionprofiles.conf b/etc/broker/x2gobroker-sessionprofiles.conf
index af3dfc2..dc79a6b 100644
--- a/etc/broker/x2gobroker-sessionprofiles.conf
+++ b/etc/broker/x2gobroker-sessionprofiles.conf
@@ -92,7 +92,7 @@ acl-groups-deny=ALL
 acl-clients-deny=ALL
 acl-clients-allow=10.1.0.0/16
 acl-any-order=deny-allow
-broker-session-autostart=true
+broker-session-autologin=true
 
 [pool-A-server-B]
 user=
@@ -104,7 +104,7 @@ acl-groups-deny=ALL
 acl-clients-deny=ALL
 acl-clients-allow=10.2.0.0/16
 acl-any-order=deny-allow
-broker-session-autostart=true
+broker-session-autologin=true
 
 [pool-A-server-C]
 user=
@@ -114,7 +114,7 @@ command=KDE
 acl-groups-allow=kde-users,admins
 acl-groups-deny=ALL
 acl-any-order=deny-allow
-broker-session-autostart=true
+broker-session-autologin=true
 
 ##
 ## EXAMPLE: pool-B (e.g. webserver in the DMZ or on the internet)
@@ -174,5 +174,5 @@ acl-groups-allow=students,admins
 acl-groups-deny=ALL
 acl-any-order=deny-allow
 # this server pool has a special broker setup for SSH authorized_keys
-broker-session-autostart=true
+broker-session-autologin=true
 broker-authorized-keys=/var/lib/x2gobroker/ssh/%u/authorized_keys
diff --git a/etc/x2gobroker.conf b/etc/x2gobroker.conf
index 6ccb3d3..24a530f 100644
--- a/etc/x2gobroker.conf
+++ b/etc/x2gobroker.conf
@@ -90,7 +90,7 @@
 # detection can be quite CPU intensive on the X2Go Broker server.
 #ignore-primary-group-memberships = true
 
-# X2Go auto-start sessions via X2Go Session Broker
+# X2Go session autologin via X2Go Session Broker
 #
 # Once authenticated against the session
 # broker, the user becomes a trusted user. That is, the X2Go session login can
@@ -99,11 +99,11 @@
 # immediately.
 #
 # This option can be overridden by the session profile parameter
-# broker-session-autostart=<file-location>
+# broker-session-autologin=<file-location>
 
-#default-session-autostart=false
+#default-session-autologin=false
 
-# X2Go's authorized_keys file for broker mediated auto-starting sessions
+# X2Go's authorized_keys file for broker mediated autologin sessions
 #
 # For the X2Go auto-login via X2Go Session Broker feature to work thoroughly,
 # the X2Go Session Broker has to place the temporary public SSH key into the
diff --git a/x2gobroker/defaults.py b/x2gobroker/defaults.py
index 4e52156..cfc7372 100644
--- a/x2gobroker/defaults.py
+++ b/x2gobroker/defaults.py
@@ -124,7 +124,7 @@ X2GOBROKER_CONFIG_DEFAULTS = {
         u'default-user-db': u'libnss',
         u'default-group-db': u'libnss',
         u'ignore-primary-group-memberships': True,
-        u'default-session-autostart': False,
+        u'default-session-autologin': False,
         u'default-authorized-keys': u'%h/.x2go/authorized_keys',
         u'default-agent-query-mode': u'LOCAL',
     },


hooks/post-receive
diff --git a/x2gobroker/brokers/base_broker.py b/x2gobroker/brokers/base_broker.py
index 57856d3..4bfd39f 100644
--- a/x2gobroker/brokers/base_broker.py
+++ b/x2gobroker/brokers/base_broker.py
@@ -464,27 +464,27 @@ class X2GoBroker(object):
 
         return unicode(_agent_query_mode) or unicode(_default_agent_query_mode)
 
-    def use_session_autostart(self, profile_id):
+    def use_session_autologin(self, profile_id):
         """\
-        Detect if the given profile is configured to try session
-        auto-starting.
+        Detect if the given profile is configured to try automatic session
+        logons.
 
-        @return: C{True} to denote that session auto-starting should be attempted
+        @return: C{True} to denote that automatic session login should be attempted
         @rtype: C{bool}
 
         """
-        _default_session_autostart = False
-        _session_autostart = False
+        _default_session_autologin = False
+        _session_autologin = False
         _profile = self.get_profile_broker(profile_id)
-        if _profile and _profile.has_key(u'broker-session-autostart') and _profile['broker-session-autostart']:
-            _session_autostart = _profile[u'broker-session-autostart']
-            logger_broker.debug('base_broker.X2GoBroker.get_session_autostart(): found broker-session-autostart in session profile with ID {id}: {value}. This one has precendence over the default value.'.format(id=profile_id, value=_session_autostart))
+        if _profile and _profile.has_key(u'broker-session-autologin') and _profile['broker-session-autologin']:
+            _session_autologin = _profile[u'broker-session-autologin']
+            logger_broker.debug('base_broker.X2GoBroker.get_session_autologin(): found broker-session-autologin in session profile with ID {id}: {value}. This one has precendence over the default value.'.format(id=profile_id, value=_session_autologin))
 
-        elif self.config.has_value('global', 'default-session-autostart'):
-            _default_session_autostart = self.config.get_value('global', 'default-session-autostart')
-            logger_broker.debug('base_broker.X2GoBroker.get_session_autostart(): found default-session-autostart in global config section: {value}'.format(value=_default_session_autostart))
+        elif self.config.has_value('global', 'default-session-autologin'):
+            _default_session_autologin = self.config.get_value('global', 'default-session-autologin')
+            logger_broker.debug('base_broker.X2GoBroker.get_session_autologin(): found default-session-autologin in global config section: {value}'.format(value=_default_session_autologin))
 
-        return _session_autostart or _default_session_autostart
+        return _session_autologin or _default_session_autologin
 
     def get_authorized_keys_file(self, profile_id):
         """\
@@ -777,7 +777,7 @@ class X2GoBroker(object):
         for profile_id in self.get_profile_ids():
             profile = self.get_profile(profile_id)
 
-            if self.use_session_autostart(profile_id):
+            if self.use_session_autologin(profile_id):
                 profile['autologin'] = True
 
             acls = self.get_profile_acls(profile_id)
@@ -849,8 +849,8 @@ class X2GoBroker(object):
                     'session_info': session_info,
                 })
 
-        # session auto-start feature
-        if self.use_session_autostart(profile_id):
+        # session autologin feature
+        if self.use_session_autologin(profile_id):
 
             # FIXME: we somehow have to find out about the username of the person at the broker client-side...
             # using the username used for broker login for now...
-- 
x2gobroker.git (HTTP(S) Session broker for X2Go)

This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "x2gobroker.git" (HTTP(S) Session broker for X2Go).




More information about the x2go-commits mailing list